Skip to contents

List summary statistics and outputs stored for an ABC result

Usage

list_abc_stored_data(x)

Arguments

x

an object returned by [abcsmc()] or [abcrejection()], or the path to an experiment directory or its `res/parquet` directory.

Value

a data frame describing available Parquet datasets.